GenerateRandomCollectionParallel

Trait GenerateRandomCollectionParallel 

pub trait GenerateRandomCollectionParallel<T>
where T: GenerateRandom + Send,
{ // Required method fn par_gen_random(amount: usize) -> Self; }
Rayon version of the GenerateRandomCollection trait

Required Methods

fn par_gen_random(amount: usize) -> Self

Generate a random collection of the inner objects with the given amount. Does not pass in rng like the sync counterpart.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<C, T> GenerateRandomCollectionParallel<T> for C

Available on crate feature rayon only.